==> fd-faq-903.0-noarch-1.txz: usr/share/doc/fd-faq/kernel.md <==
%%textdomain fatdoghelp

 
![Fatdog64 logo](img/fatdog64-header.png)

#  
# How to use a different kernel
#  

This instruction is for using one of the pre-packaged Fatdog kernels, replacing the current one that comes with your version of Fatdog. If instead, you just want to add some additional kernel modules you've built yourself; or if you compile a totally new kernel, please follow the instructions in [here](initrd.md) to rebuild and replace the kernel-modules.sfs in initrd.

There a a couple ways to use a different kernel. First go [here](http://distro.ibiblio.org/fatdog/kernels/) and download vmlinuz-x.x.x and kernel-modules.sfs-x.x.x, where x.x.x is the kernel version that you want. Vmlinuz is the actual kernel and kernel-modules.sfs contains the kernel modules (drivers) that are built to work with it.

Preferred method - Replace the original kernel-modules.sfs in the initrd with the one you downloaded:

1)  Click on your initrd file. After a while the initrd will be extracted into a working folder and a new ROX window will open.

2)  Replace the kernel-modules.sfs with the one you downloaded. Make sure it's named "kernel-modules.sfs".

3)  Click on repack-initrd and the initrd will be updated.

4)  Replace the original vmlinuz with the one you downloaded.

Alternate method - Using hard drive install booting with grub:

1)  Copy vmlinuz-x.x.x to the same place as your original vmlinuz.

2)  Rename kernel-modules.sfs-x.x.x to kernel-modules.sfs then click on it to mount it. A ROX file browser window will pop up.

3)  From the mounted kernel-modules.sfs copy lib/modules/x.x.x to your system /lib/modules/.

4)  Then you can add a new entry for grub in menu.lst, just like your current entry but with the kernel named vmlinuz-x.x.x.

5)  Reboot using your new kernel.

You can also compile a new kernel by downloading the source from [here](https://www.kernel.org/) , installing the devx sfs, and compiling.


----

[Fatdog64](home.md)
| [FAQ index](faq.md)
| [FAQ files](faq_file_list.md)
| [Fatdog64 online](https://distro.ibiblio.org/fatdog/web)
| [FAQ online](https://distro.ibiblio.org/fatdog/web/faqs/faq.html)

----

_This page was automatically converted from [kernel.html](https://distro.ibiblio.org/fatdog/web/faqs/kernel.html) on 2024-08-05._

==> fd-faq-904.0-noarch-1.txz: usr/share/doc/fd-faq/kernel.md <==
 
![Fatdog64 logo](img/fatdog64-header.png)


# How to use a different kernel

This instruction is for using one of the pre-packaged Fatdog kernels, replacing the current one that comes with your version of Fatdog. If instead, you just want to add some additional kernel modules you've built yourself; or if you compile a totally new kernel, please follow the instructions in [here](initrd.md) to rebuild and replace the kernel-modules.sfs in initrd.  
There a a couple ways to use a different kernel. First go [here](http://distro.ibiblio.org/fatdog/kernels/) and download vmlinuz-x.x.x and kernel-modules.sfs-x.x.x, where x.x.x is the kernel version that you want. Vmlinuz is the actual kernel and kernel-modules.sfs contains the kernel modules (drivers) that are built to work with it.  
Preferred method - Replace the original kernel-modules.sfs in the initrd with the one you downloaded:  
1)  Click on your initrd file. After a while the initrd will be extracted into a working folder and a new ROX window will open.  
2)  Replace the kernel-modules.sfs with the one you downloaded. Make sure it's named "kernel-modules.sfs".  
3)  Click on repack-initrd and the initrd will be updated.  
4)  Replace the original vmlinuz with the one you downloaded.  
Alternate method - Using hard drive install booting with grub:  
1)  Copy vmlinuz-x.x.x to the same place as your original vmlinuz.  
2)  Rename kernel-modules.sfs-x.x.x to kernel-modules.sfs then click on it to mount it. A ROX file browser window will pop up.  
3)  From the mounted kernel-modules.sfs copy lib/modules/x.x.x to your system /lib/modules/.  
4)  Then you can add a new entry for grub in menu.lst, just like your current entry but with the kernel named vmlinuz-x.x.x.  
5)  Reboot using your new kernel.  
You can also compile a new kernel by downloading the source from [here](https://www.kernel.org/) , installing the devx sfs, and compiling. There is an example of how to do that [here](kernel-build.md).  


----

[Fatdog64](home.md)
| [FAQ index](faq.md)
| [FAQ files](faq_file_list.md)
| [Fatdog64 online](https://distro.ibiblio.org/fatdog/web)
| [FAQ online](https://distro.ibiblio.org/fatdog/web/faqs/faq.html)

----

_This page was automatically converted from [kernel.html](https://distro.ibiblio.org/fatdog/web/faqs/kernel.html) on 2025-03-07._
